@@ -10,6 +10,7 @@ import module_build_service.common.scm
 from module_build_service.common import conf, log
 from module_build_service.common.errors import ValidationError
 from module_build_service.common.utils import load_mmd_file
+from module_build_service.common.modulemd import Modulemd
 
 
 def _is_eol_in_pdc(name, stream):
@@ -46,7 +47,8 @@ def fetch_mmd(url, branch=None, allow_local_url=False, whitelist_url=False, mand
         if not whitelist_url and mandatory_checks:
             scm.verify()
         cofn = scm.get_module_yaml()
-        mmd = load_mmd_file(cofn)
+        # load_mmd_file can return either a ModuleStreamV2 or PackagerV3 object
+        stream_or_packager = load_mmd_file(cofn)
     finally:
         try:
             if td is not None:
@@ -60,38 +62,51 @@ def fetch_mmd(url, branch=None, allow_local_url=False, whitelist_url=False, mand
                 "Module {}:{} is marked as EOL in PDC.".format(scm.name, scm.branch))
 
     if not mandatory_checks:
-        return mmd, scm
+        return stream_or_packager, scm
 
     # If the name was set in the modulemd, make sure it matches what the scmurl
     # says it should be
-    if mmd.get_module_name() and mmd.get_module_name() != scm.name:
+    if stream_or_packager.get_module_name() and stream_or_packager.get_module_name() != scm.name:
         if not conf.allow_name_override_from_scm:
             raise ValidationError(
                 'The name "{0}" that is stored in the modulemd is not valid'
-                .format(mmd.get_module_name())
+                .format(stream_or_packager.get_module_name())
             )
     else:
         # Set the module name
-        mmd = mmd.copy(scm.name)
+        if isinstance(stream_or_packager, Modulemd.ModuleStream):
+            # this is a ModuleStreamV2 object
+            stream_or_packager = stream_or_packager.copy(scm.name)
+        else:
+            # this is a PackagerV3 object
+            stream_or_packager = stream_or_packager.copy()
+            stream_or_packager.set_module_name(scm.name)
 
     # If the stream was set in the modulemd, make sure it matches what the repo
     # branch is
-    if mmd.get_stream_name() and mmd.get_stream_name() != scm.branch:
+    if stream_or_packager.get_stream_name() and stream_or_packager.get_stream_name() != scm.branch:
         if not conf.allow_stream_override_from_scm:
             raise ValidationError(
                 'The stream "{0}" that is stored in the modulemd does not match the branch "{1}"'
-                .format(mmd.get_stream_name(), scm.branch)
+                .format(stream_or_packager.get_stream_name(), scm.branch)
             )
     else:
         # Set the module stream
-        mmd = mmd.copy(mmd.get_module_name(), scm.branch)
+        if isinstance(stream_or_packager, Modulemd.ModuleStream):
+            # this is a ModuleStreamV2 object
+            stream_or_packager = stream_or_packager.copy(stream_or_packager.get_module_name(),
+                                                         scm.branch)
+        else:
+            # this is a PackagerV3 object
+            stream_or_packager = stream_or_packager.copy()
+            stream_or_packager.set_stream_name(scm.branch)
 
     # If the version is in the modulemd, throw an exception since the version
     # since the version is generated by MBS
-    if mmd.get_mdversion() == 2 and mmd.get_version():
+    if stream_or_packager.get_mdversion() == 2 and stream_or_packager.get_version():
         raise ValidationError(
             'The version "{0}" is already defined in the modulemd but it shouldn\'t be since the '
-            "version is generated based on the commit time".format(mmd.get_version())
+            "version is generated based on the commit time".format(stream_or_packager.get_version())
         )
 
-    return mmd, scm
+    return stream_or_packager, scm
