@@ -308,6 +308,7 @@ class DBResolver(GenericResolver):
             )
 
         buildrequires = xmd_mbs["buildrequires"]
+        side_tag = xmd_mbs.get("side_tag")
         for br_name, details in buildrequires.items():
             build = models.ModuleBuild.get_build_from_nsvc(
                 self.db_session,
@@ -321,12 +322,23 @@ class DBResolver(GenericResolver):
                 raise RuntimeError(
                     "Buildrequired module %s %r does not exist in MBS db" % (br_name, details))
 
+            koji_tag = build.koji_tag
+            if side_tag and br_name in self.config.base_module_names:
+                # see if base module has a side tag configuration
+                side_tag_format = build.mmd().get_xmd().get("mbs", {}).get("koji_side_tag_format")
+                if side_tag_format:
+                    koji_tag = side_tag_format.format(side_tag=side_tag)
+                    log.info("Using side tag for base module %s: %s", br_name, koji_tag)
+                else:
+                    log.warning("Side tag requested, but base module %s lacks koji_side_tag_format"
+                                " value", br_name)
+
             # If the buildrequire is a meta-data only module with no Koji tag set, then just
             # skip it
-            if build.koji_tag is None:
+            if koji_tag is None:
                 continue
-            module_tags.setdefault(build.koji_tag, [])
-            module_tags[build.koji_tag].append(build.mmd())
+            module_tags.setdefault(koji_tag, [])
+            module_tags[koji_tag].append(build.mmd())
 
         return module_tags
 
