@@ -2,42 +2,72 @@
 # SPDX-License-Identifier: MIT
 """ Handlers for koji component build events on the message bus. """
 
+from __future__ import absolute_import
 import logging
-import koji
-import module_build_service.builder
 
-from module_build_service.builder.KojiModuleBuilder import KojiModuleBuilder
-from module_build_service.utils.general import mmd_to_str
-from module_build_service import models, log, messaging
+import koji
+
+from module_build_service.builder import GenericBuilder
+from module_build_service.common import conf, log, models
+from module_build_service.common.koji import get_session
+from module_build_service.common.utils import mmd_to_str
+from module_build_service.scheduler import celery_app, events
+from module_build_service.scheduler.batches import continue_batch_build
+from module_build_service.scheduler.db_session import db_session
 
 logging.basicConfig(level=logging.DEBUG)
 
 
-def _finalize(config, db_session, msg, state):
-    """ Called whenever a koji build completes or fails. """
+@celery_app.task
+@events.mbs_event_handler
+def build_task_finalize(
+        msg_id, task_id, build_new_state,
+        build_name, build_version, build_release,
+        module_build_id=None, state_reason=None
+):
+    """Called when corresponding Koji build task of a component build finishes
+
+    When a task finishes, the task could be in state COMPLETE, FAILED or CANCELED.
+
+    :param str msg_id: the original id of the message being handled which is
+        received from the message bus.
+    :param int task_id: the Koji build task id.
+    :param int build_new_state: the state of the build. Refer to
+        ``koji.BUILD_STATES`` for details. For this handler, values could be
+        the corresponding integer value of COMPLETE, FAILED or CANCELED.
+    :param str build_name: the build name.
+    :param str build_version: the build version.
+    :param str build_release: the build release.
+    :param int module_build_id: optionally set when this event handler is
+        scheduled from internal rather than just handling the received message.
+        When set, the value should be the id of module build having the
+        component build just built by the finished task.
+    :param str state_reason: optional. When set a reason explicitly, the
+        corresponding component build will have this reason as the
+        ``state_reason``. Otherwise, a custom reason will be set for a failed
+        build.
+    """
 
     # First, find our ModuleBuild associated with this component, if any.
-    component_build = models.ComponentBuild.from_component_event(db_session, msg)
-    try:
-        nvr = "{}-{}-{}".format(msg.build_name, msg.build_version, msg.build_release)
-    except KeyError:
-        nvr = None
+    component_build = models.ComponentBuild.from_component_event(
+        db_session, task_id, module_id=module_build_id)
+    nvr = "{}-{}-{}".format(build_name, build_version, build_release)
 
     if not component_build:
-        log.debug("We have no record of %s" % nvr)
+        log.debug("We have no record of %s", nvr)
         return
 
-    log.info("Saw relevant component build of %r from %r." % (nvr, msg.msg_id))
+    log.info("Saw relevant component build of %r from %r.", nvr, msg_id)
 
-    if msg.state_reason:
-        state_reason = msg.state_reason
-    elif state != koji.BUILD_STATES["COMPLETE"]:
-        state_reason = "Failed to build artifact %s in Koji" % (msg.build_name)
+    if state_reason:
+        state_reason = state_reason
+    elif build_new_state != koji.BUILD_STATES["COMPLETE"]:
+        state_reason = "Failed to build artifact {} in Koji".format(build_name)
     else:
         state_reason = ""
 
     # Mark the state in the db.
-    component_build.state = state
+    component_build.state = build_new_state
     component_build.nvr = nvr
     component_build.state_reason = state_reason
     db_session.commit()
@@ -45,10 +75,11 @@ def _finalize(config, db_session, msg, state):
     parent = component_build.module_build
 
     # If the macro build failed, then the module is doomed.
-    if component_build.package == "module-build-macros" and state != koji.BUILD_STATES["COMPLETE"]:
+    if (component_build.package == "module-build-macros"
+            and build_new_state != koji.BUILD_STATES["COMPLETE"]):
         parent.transition(
             db_session,
-            config,
+            conf,
             state=models.BUILD_STATES["failed"],
             state_reason=state_reason,
             failure_type="user",
@@ -58,10 +89,10 @@ def _finalize(config, db_session, msg, state):
 
     if (
         component_build.buildonly
-        and config.system in ["koji", "test"]
-        and state == koji.BUILD_STATES["COMPLETE"]
+        and conf.system in ["koji", "test"]
+        and build_new_state == koji.BUILD_STATES["COMPLETE"]
     ):
-        koji_session = KojiModuleBuilder.get_session(config)
+        koji_session = get_session(conf, login=False)
         rpms = koji_session.listBuildRPMs(component_build.nvr)
         mmd = parent.mmd()
         for artifact in rpms:
@@ -69,8 +100,6 @@ def _finalize(config, db_session, msg, state):
         parent.modulemd = mmd_to_str(mmd)
         db_session.commit()
 
-    further_work = []
-
     parent_current_batch = parent.current_batch()
 
     # If there are no other components still building in a batch,
@@ -83,9 +112,7 @@ def _finalize(config, db_session, msg, state):
         failed_components_in_batch = [c for c in parent_current_batch if c.is_unsuccessful]
         built_components_in_batch = [c for c in parent_current_batch if c.is_completed]
 
-        builder = module_build_service.builder.GenericBuilder.create_from_module(
-            db_session, parent, config
-        )
+        builder = GenericBuilder.create_from_module(db_session, parent, conf)
 
         if failed_components_in_batch:
             log.info(
@@ -96,7 +123,7 @@ def _finalize(config, db_session, msg, state):
                 ", ".join(c.package for c in failed_components_in_batch))
             parent.transition(
                 db_session,
-                config,
+                conf,
                 state=models.BUILD_STATES["failed"],
                 state_reason=state_reason,
                 failure_type="user",
@@ -108,10 +135,9 @@ def _finalize(config, db_session, msg, state):
             # The repository won't be regenerated in this case and therefore we generate fake repo
             # change message here.
             log.info("Batch done. No component to tag")
-            further_work += [
-                messaging.KojiRepoChange(
-                    "components::_finalize: fake msg", builder.module_build_tag["name"])
-            ]
+            from module_build_service.scheduler.handlers.repos import done as repos_done_handler
+            events.scheduler.add(
+                repos_done_handler, ("fake_msg", builder.module_build_tag["name"]))
         else:
             built_component_nvrs_in_batch = [c.nvr for c in built_components_in_batch]
             # tag && add to srpm-build group if neccessary
@@ -146,21 +172,5 @@ def _finalize(config, db_session, msg, state):
         # done in repos.py:done(...), but because we have just finished one
         # build, try to call continue_batch_build again so in case we hit the
         # threshold previously, we will submit another build from this batch.
-        builder = module_build_service.builder.GenericBuilder.create_from_module(
-            db_session, parent, config)
-        further_work += module_build_service.utils.continue_batch_build(
-            config, parent, db_session, builder)
-
-    return further_work
-
-
-def complete(config, db_session, msg):
-    return _finalize(config, db_session, msg, state=koji.BUILD_STATES["COMPLETE"])
-
-
-def failed(config, db_session, msg):
-    return _finalize(config, db_session, msg, state=koji.BUILD_STATES["FAILED"])
-
-
-def canceled(config, db_session, msg):
-    return _finalize(config, db_session, msg, state=koji.BUILD_STATES["CANCELED"])
+        builder = GenericBuilder.create_from_module(db_session, parent, conf)
+        continue_batch_build(conf, parent, builder)
