@@ -1,22 +1,26 @@
 # -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MIT
-import pytest
+from __future__ import absolute_import
 from datetime import datetime
 
+import pytest
+
+from module_build_service.common.config import conf
+from module_build_service.common.models import ModuleBuild
+from module_build_service.common.utils import import_mmd, load_mmd, mmd_to_str
+from module_build_service.scheduler.db_session import db_session
 import module_build_service.resolver as mbs_resolver
-from module_build_service.utils.general import import_mmd, mmd_to_str, load_mmd
-from module_build_service.models import ModuleBuild
 import tests
 
 
 @pytest.mark.usefixtures("reuse_component_init_data")
 class TestLocalResolverModule:
 
-    def test_get_buildrequired_modulemds(self, db_session):
+    def test_get_buildrequired_modulemds(self):
         mmd = load_mmd(tests.read_staged_data("platform"))
         mmd = mmd.copy(mmd.get_module_name(), "f8")
         import_mmd(db_session, mmd)
-        platform_f8 = ModuleBuild.query.filter_by(stream="f8").one()
+        platform_f8 = db_session.query(ModuleBuild).filter_by(stream="f8").one()
         mmd = mmd.copy("testmodule", "master")
         mmd.set_version(20170109091357)
         mmd.set_context("123")
@@ -40,7 +44,7 @@ class TestLocalResolverModule:
         db_session.add(build)
         db_session.commit()
 
-        resolver = mbs_resolver.GenericResolver.create(db_session, tests.conf, backend="local")
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="local")
         result = resolver.get_buildrequired_modulemds(
             "testmodule", "master", platform_f8.mmd().get_nsvc())
         nsvcs = {m.get_nsvc() for m in result}
