@@ -17,7 +17,7 @@ from module_build_service.common.utils import (mmd_to_str, load_mmd,
 from module_build_service.scheduler.db_session import db_session
 from module_build_service.web.submit import (
     get_prefixed_version, submit_module_build, submit_module_build_from_yaml,
-    process_module_context_configuration
+    process_module_context_configuration, _apply_side_tag,
 )
 from tests import (
     scheduler_init_data,
@@ -218,6 +218,53 @@ class TestProcessModuleContextConfiguration:
             assert stream.is_static_context()
 
 
+class TestApplySideTag:
+    def get_mmd(self):
+        yaml_str = """
+document: modulemd
+version: 2
+data:
+    name: app
+    stream: test
+    summary: "A test module"
+    description: >
+        "A test module stream"
+    license:
+        module: [ MIT ]
+    dependencies:
+        - buildrequires:
+            platform: []
+            gtk: []
+          requires:
+            platform: []
+            gtk: []
+        """
+        return load_mmd(yaml_str)
+
+    def test_apply_side_tag(self):
+        """
+        Test that the side tag option is correctly added into the xmd
+        """
+        mmd = self.get_mmd()
+        side_tag = "SIDETAG"
+        _apply_side_tag(mmd, {"side_tag": side_tag})
+
+        xmd = mmd.get_xmd()
+        assert xmd["mbs"]["side_tag"] == side_tag
+
+    def test_apply_side_tag_no_option(self):
+        """
+        Test that the xmd is unchanged when option not given
+        """
+        mmd = self.get_mmd()
+        xmd_orig = mmd.get_xmd()
+        _apply_side_tag(mmd, {})
+
+        xmd = mmd.get_xmd()
+        assert xmd == xmd_orig
+        assert "side_tag" not in xmd.get("mbs", {})
+
+
 @pytest.mark.usefixtures("reuse_component_init_data")
 class TestUtilsComponentReuse:
     @mock.patch("module_build_service.web.submit.submit_module_build")
@@ -253,6 +300,36 @@ class TestUtilsComponentReuse:
             assert username_arg == username
         rmtree(module_dir)
 
+    @mock.patch("module_build_service.web.submit.submit_module_build")
+    def test_submit_module_build_from_yaml_packager_v3(self, mock_submit):
+        """
+        Tests local module build from a yaml file with the skiptests option
+
+        Args:
+            mock_submit (MagickMock): mocked function submit_module_build, which we then
+                inspect if it was called with correct arguments
+        """
+        module_dir = tempfile.mkdtemp()
+        modulemd_yaml = read_staged_data("v3/mmd_packager")
+        modulemd_file_path = path.join(module_dir, "testmodule.yaml")
+
+        username = "test"
+        stream = "dev"
+
+        with io.open(modulemd_file_path, "w", encoding="utf-8") as fd:
+            fd.write(modulemd_yaml)
+
+        with open(modulemd_file_path, "rb") as fd:
+            handle = FileStorage(fd)
+            submit_module_build_from_yaml(
+                db_session, username, handle, {}, stream=stream, skiptests=False)
+            mock_submit_args = mock_submit.call_args[0]
+            username_arg = mock_submit_args[1]
+            mmd_arg = mock_submit_args[2]
+            assert mmd_arg.get_stream_name() == stream
+            assert username_arg == username
+        rmtree(module_dir)
+
     @mock.patch("module_build_service.web.submit.generate_expanded_mmds")
     def test_submit_build_new_mse_build(self, generate_expanded_mmds):
         """
